Stan Math Library: stan/math/rev/core/std_isinf.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

std_isinf.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_STD_ISINF_HPP
2 #define STAN_MATH_REV_CORE_STD_ISINF_HPP
3
4 #include <stan/math/rev/core/var.hpp>
5 #include <cmath>
6
7 namespace std {
8
18 inline int isinf(const stan::math::var& a) {
19 return isinf(a.val());
20 }
21
22 }
23 #endif
std::isinf
int isinf(const stan::math::var &a)
Checks if the given number is infinite.
Definition: std_isinf.hpp:18
std
Definition: std_numeric_limits.hpp:7
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
var.hpp
stan::math::var::val
double val() const
Return the value of this variable.
Definition: var.hpp:233

[ Stan Home Page ] © 2011–2016, Stan Development Team.